<?php
if ($_SERVER["REQUEST_METHOD"] == "POST") {
    // serve per ottenere il valore dell'IDUtente inviato tramite il form.
    $IDUtente = isset($_POST['IDUtente']) ? $_POST['IDUtente'] : '';

    if (empty($IDUtente)) {
        echo "IDUtente non valido";
        exit;
    }

    // Connessione al database
    $conn = new mysqli("localhost", "root", "", "my_truckmanagement");
    if ($conn->connect_errno) {
        echo "Impossibile connettersi al server: " . $conn->connect_error;
        exit;
    }

    // Disattiva i vincoli di chiave esterna temporaneamente
    $conn->query("SET FOREIGN_KEY_CHECKS=0");

    // Inizio transazione
    $conn->begin_transaction();

    // Query per eliminare le fermate
    $sql_fermate = "DELETE FROM fermate WHERE IDViaggio IN (SELECT IDViaggio FROM viaggio WHERE IDCamion IN (SELECT IDCamion FROM camion WHERE IDUtente = ?))";
    $stmt_fermate = $conn->prepare($sql_fermate);
    if ($stmt_fermate) {
        $stmt_fermate->bind_param("s", $IDUtente);
        $stmt_fermate->execute();
        $stmt_fermate->close();
    } else {
        echo "Errore nella preparazione della query per le fermate: " . $conn->error;
        $conn->rollback();
        exit;
    }

    // Query per eliminare le manutenzioni
    $sql_manutenzioni = "DELETE FROM manutenzione WHERE IDCamion IN (SELECT IDCamion FROM camion WHERE IDUtente = ?)";
    $stmt_manutenzioni = $conn->prepare($sql_manutenzioni);//La query SQL viene preparata usando il metodo prepare dell'oggetto mysqli. La preparazione della query permette di eseguire query SQL con parametri variabili in modo sicuro, prevenendo attacchi di SQL injection.
    if ($stmt_manutenzioni) { //Il codice verifica se la preparazione della query è riuscita. 
        $stmt_manutenzioni->bind_param("s", $IDUtente);//Viene associato il parametro IDUtente alla query preparata.s indica che il parametro associato è una stringa.
        $stmt_manutenzioni->execute();//La query preparata viene eseguita.
        $stmt_manutenzioni->close();
    } else {
        echo "Errore nella preparazione della query per le manutenzioni: " . $conn->error; //messaggio di errore se fallisce la preparazione
        $conn->rollback();
        exit;
    }

    // Query per eliminare i viaggi
    $sql_viaggi = "DELETE FROM viaggio WHERE IDCamion IN (SELECT IDCamion FROM camion WHERE IDUtente = ?)";
    $stmt_viaggi = $conn->prepare($sql_viaggi);
    if ($stmt_viaggi) {
        $stmt_viaggi->bind_param("s", $IDUtente);
        $stmt_viaggi->execute();
        $stmt_viaggi->close();
    } else {
        echo "Errore nella preparazione della query per i viaggi: " . $conn->error;
        $conn->rollback();
        exit;
    }

    // Query per eliminare i camion
    $sql_camion = "DELETE FROM camion WHERE IDUtente = ?";
    $stmt_camion = $conn->prepare($sql_camion);
    if ($stmt_camion) {
        $stmt_camion->bind_param("s", $IDUtente);
        $stmt_camion->execute();
        $stmt_camion->close();
    } else {
        echo "Errore nella preparazione della query per i camion: " . $conn->error;
        $conn->rollback();
        exit;
    }

    // Query per eliminare l'utente
    $sql_utente = "DELETE FROM utente WHERE IDUtente = ?";
    $stmt_utente = $conn->prepare($sql_utente);
    if ($stmt_utente) {
        $stmt_utente->bind_param("s", $IDUtente);
        $stmt_utente->execute();
        $stmt_utente->close();
    } else {
        echo "Errore nella preparazione della query per l'utente: " . $conn->error;
        $conn->rollback();
        exit;
    }

    // Questa linea di codice conferma (commits) tutte le operazioni eseguite
    $conn->commit();

    echo "<script>";
    echo "alert('Cancellazione avvenuta con successo');";
    echo "window.location.href = 'https://truckmanagement.altervista.org/Lato_Direttore/Area_Direttore/Area_Direttore.html';";
    echo "</script>";

    // Chiudi la connessione al database 
    $conn->close();
} else {
    // Se il metodo della richiesta non è POST, reindirizza l'utente sull'errore di conseguenza
    echo "Metodo non consentito";
}
?>
